dhcpkit.ipv6.extensions.ntp_suboption_registry module
=====================================================

.. automodule:: dhcpkit.ipv6.extensions.ntp_suboption_registry
    :members:
    :undoc-members:
    :show-inheritance:
